<?php
$page_title = "API Signature Settings";
include_once('template/base_head.php');
?>
			<!-- サイドバー -->
			<aside id="colLeft">
				<h1><a href=""><img src="../img/logo.png" alt="iWallet"></a></h1>
				<div class="aside-heading">
					&nbsp;
				</div>
				&nbsp;
			</aside>
			<!-- /サイドバー -->
			<!-- メインカラム -->
			<div id="colMain">
				<div class="mainIn">
<?php include_once('template/base_nav.php'); ?>
					<article>
						<div class="article-heading">
							<h2><?php echo $page_title; ?></h2>
						</div>
						<?php $this -> echoMessage(); ?>
						<form id="acForm" action="" method="post">
							<table class="table col bdr default odd w60p fontXS m_auto mb20">
								<colgroup>
									<col class="w40p">
									<col class="w60p">
								</colgroup>
								<tr>
									<th>Account Number</th>
									<td><?php $this -> echoUserAccount(); ?></td>
								</tr>
								<tr>
									<th>Name</th>
									<td>
										<?php $this -> echoLastName(); ?> <?php $this -> echoFirstName(); ?>
									</td>
								</tr>
								<tr>
									<th>API Username</th>
									<td>
										<input type="text" id="user_name" name="user_name" value="<?php $this -> echoUserName(); ?>" class="w30p">

									</td>
								</tr>
								<tr>
									<th>API Password</th>
									<td>
										<input type="text" id="password" data-lpignore="true" name="password" value="<?php $this -> echoPassword(); ?>" class="w30p">
										<a href="#" id="create_password">Generate Password</a>
									</td>
								</tr>
								<tr>
									<th>IP Address</th>
									<td>
										<textarea id="ip_address" name="ip_address" rows="10" cols="50"><?php $this -> echoIpAddress(); ?></textarea>
									</td>
								</tr>
								<tr>
									<th>Domain Name</th>
									<td>
										<textarea id="domain_name" name="domain_name" rows="10" cols="50"><?php $this -> echoDomainName(); ?></textarea>
									</td>
								</tr>
								<tr>
									<th>Validation Settings</th>
									<td>
										<?php $this -> echoWhitelistSettingsCheckboxes(); ?>
									</td>
								</tr>
							</table>

							<input type="hidden" value="action" id="type" name="type" />
							<input type="hidden" value="<?php $this -> echoUserAccount(); ?>" id="user_account" name="user_account" />
							
							<!-- Language Transition Data (Anton) 04/23/2016 -->
							<input class="lang-trans-data" type="hidden" id="lang_data_action" value="/api_signature"/>
							<input class="lang-trans-data" type="hidden" id="lang_data_form" value="#acForm"/>
							<input class="lang-trans-data" type="hidden" id="lang_data_type" value="input"/>
							<!-- /Language Transition Data -->
						</form>
						<p class="calign">
							<a href="" class="btn bg-default">&laquo; Back</a>&emsp;
							<input type="button" id="btnConfirm" value="Confirm" class="btn bg-grad px80 hi25">
						</p>
						<div class="article-bottom">
						</div>
					</article>
				</div>
			</div>
			<!-- /メインカラム -->
		</div>
<?php include_once('template/base_foot.php'); ?>
	</div>

	<script src="../js/api_signature.js"></script>
</body>
</html>
